package com.ruoyi.project.business.mapper.quotation;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.project.business.domain.TqBargainPrice;
import java.util.List;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author ruoyi
 * @date 2024-05-21
 */
public interface TqBargainPriceMapper extends BaseMapper<TqBargainPrice> {

    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public TqBargainPrice selectTqBargainPriceById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param tqBargainPrice 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TqBargainPrice> selectTqBargainPriceList(TqBargainPrice tqBargainPrice);

    /**
     * 新增【请填写功能名称】
     *
     * @param tqBargainPrice 【请填写功能名称】
     * @return 结果
     */
    public int insertTqBargainPrice(TqBargainPrice tqBargainPrice);

    /**
     * 修改【请填写功能名称】
     *
     * @param tqBargainPrice 【请填写功能名称】
     * @return 结果
     */
    public int updateTqBargainPrice(TqBargainPrice tqBargainPrice);

    /**
     * 删除【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteTqBargainPriceById(Long id);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTqBargainPriceByIds(Long[] ids);
}
