package com.ruoyi.project.business.controller.quotation;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.framework.web.page.TableDataInfo;
import com.ruoyi.project.business.domain.TqBargainPrice;
import com.ruoyi.project.business.domain.bo.quotation.BargainPriceAddBO;
import com.ruoyi.project.business.service.quotation.ITqBargainPriceService;
import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 【请填写功能名称】Controller
 *
 * @author ruoyi
 * @date 2024-05-21
 */
@RestController
@RequestMapping("/business/bargain/price")
public class TqBargainPriceController extends BaseController {

    @Resource
    private ITqBargainPriceService tqBargainPriceService;

    /**
     * 查询【请填写功能名称】列表
     */
    // @PreAuthorize("@ss.hasPermi('system:price:list')")
    @GetMapping("/list")
    public TableDataInfo list(TqBargainPrice tqBargainPrice) {
        startPage();
        List<TqBargainPrice> list = tqBargainPriceService.selectTqBargainPriceList(tqBargainPrice);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    // @PreAuthorize("@ss.hasPermi('system:price:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TqBargainPrice tqBargainPrice) {
        List<TqBargainPrice> list = tqBargainPriceService.selectTqBargainPriceList(tqBargainPrice);
        ExcelUtil<TqBargainPrice> util = new ExcelUtil<TqBargainPrice>(TqBargainPrice.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    // @PreAuthorize("@ss.hasPermi('system:price:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tqBargainPriceService.selectTqBargainPriceById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:price:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TqBargainPrice tqBargainPrice) {
        return toAjax(tqBargainPriceService.insertTqBargainPrice(tqBargainPrice));
    }

    /**
     * 修改【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:price:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TqBargainPrice tqBargainPrice) {
        return toAjax(tqBargainPriceService.updateTqBargainPrice(tqBargainPrice));
    }

    /**
     * 删除【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:price:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tqBargainPriceService.deleteTqBargainPriceByIds(ids));
    }

    // @PreAuthorize("@ss.hasPermi('system:price:export')")
    @Log(title = "【发起议价】", businessType = BusinessType.INSERT)
    @PostMapping("/start")
    public AjaxResult startBargainPrice(@RequestBody BargainPriceAddBO bargainPriceAddBO) {
        tqBargainPriceService.startBargainPrice(bargainPriceAddBO);
        return success();
    }

    // @PreAuthorize("@ss.hasPermi('system:price:export')")
    @Log(title = "【接受价格】", businessType = BusinessType.INSERT)
    @GetMapping("/accept/{quotationId}")
    public AjaxResult acceptBargainPrice(@PathVariable Long quotationId) {
        tqBargainPriceService.acceptBargainPrice(quotationId);
        return success();
    }

    // @PreAuthorize("@ss.hasPermi('system:price:export')")
    @Log(title = "【驳回价格】", businessType = BusinessType.INSERT)
    @GetMapping("/reject/{quotationId}")
    public AjaxResult rejectBargainPrice(@PathVariable Long quotationId) {
        tqBargainPriceService.rejectBargainPrice(quotationId);
        return success();
    }


}
